%Kim Ruhl May 20, 2004
%This file loads the data and parameters for the model and calls the
%SolveModel function. To run this script, make sure this file is in your
%working directory, or the directory is in the MATLAB path. Then simply
%type "depressions" without quotes, to run the script.

%The file "param.txt" is a column vector with the following ordering of parameters:
%beta, gamma, delta, alpha, growth rate, initial capital stock.

% The file "data.txt" is a Tx6 matrix where rows are years, and columns are:
% TFP, working age pop. (in 1000s), available hours, consumption tax rate, labor tax rate, capital tax rate.

%Clear the workspace and load parameters and data.  These files can be
%created by Excel using the "save as tab delimited text" option.
clear;
load('param.txt');
load('data.txt');
param = timparam;
data = timdata;

%delcare the global parameters
global BETA;    global GAMMA;   global DELTA;   global ALPHA;   global G;
global K1;      global T;       global a;       global pop;     global lbar;
global tauc;     global taul;    global tauk;

%assign them values from the file
BETA = param(1);    %discount factor    
GAMMA = param(2);   %utility function parameter
DELTA = param(3);   %depreciation rate
ALPHA = param(4);   %capital's share
G = param(5);       %growth rate of consumption
K1 = param(6);      %initial capital stock


T= size(data,1);    %number of periods
a = zeros(T,1);     %TFP
lbar = zeros(T,1);  %available labor hours 
pop = zeros(T,1);   %working age population
tauc = zeros(T,1);  %consumption tax rate
taul = zeros(T,1);  %labor income tax rate
tauk = zeros(T,1);  %capital income tax rate

%assign the values from the file
for i = 1:T
    a(i) = data(i,1);
    pop(i) = data(i,2);
    lbar(i) = data(i,3);
    tauc(i) = data(i,4);
    taul(i) = data(i,5);
    tauk(i) = data(i,6);
end

z = zeros(1,1);      %dummy argument for SolveModel function

%Call SolveModel, and check for success
if  0 == SolveModel(z)
    fprintf('Model solved successfully.');
else
    fprintf('Could not find model solution.');
end




        
